render_plain

Function render_plain 

pub fn render_plain(renderable: &dyn Renderable, width: usize) -> String
Render renderable at width through a plain, deterministic target. Trailing whitespace on each line and trailing blank lines are dropped.