pub fn diff_lines(old: &[&str], new: &[&str]) -> Vec<Op>
Diff two sequences of lines. Include line terminators in the elements when a missing final newline should count as a change, as diff does.
diff