StructuredEvent

Struct StructuredEvent 

pub struct StructuredEvent {
    pub message: Message,
    pub fields: Vec<(String, Value)>,
    pub context: EventContext,
    /* private fields */
}

Fields

message: Messagefields: Vec<(String, Value)>context: EventContext

Implementations

Source

impl StructuredEvent

pub fn new(message: Message) -> Self

pub fn diagnostic(self, diagnostic: Diagnostic) -> Self

pub fn field(self, key: impl Into<String>, value: Value) -> Self

pub fn field_order(self, keys: Vec<String>) -> Self

pub fn hide_fields(self, keys: Vec<String>) -> Self

pub fn view(self, view: EventView) -> Self

pub fn context(self, context: EventContext) -> Self

pub fn overflow(self, overflow: OverflowPolicy) -> Self

pub fn spans(self, spans: Vec<SpanContext>) -> Self

The spans the event happened in, outermost first.

pub fn span_event(self, event: SpanEvent) -> Self

Mark the event as a span opening or closing. Its message is the span’s name, its fields the span’s, and spans its parents.

pub fn span_context(&self) -> &[SpanContext]

The spans the event happened in, outermost first.

pub fn span_marker(&self) -> Option<SpanEvent>

Whether the event reports a span opening or closing.