pub struct ResolvedRules<'a> { /* private fields */ }Expand description
StyleRules resolved against one table, from
StyleRules::resolve.
Implementations
Sourceimpl ResolvedRules<'_>
impl ResolvedRules<'_>
Sourcepub fn row_style(&self, row: &[Value]) -> Option<Style>
pub fn row_style(&self, row: &[Value]) -> Option<Style>
The style for the whole of row: its row rules that match, combined.
Sourcepub fn cell_style(&self, row: &[Value], column: usize) -> Option<Style>
pub fn cell_style(&self, row: &[Value], column: usize) -> Option<Style>
The style for row’s cell in column: the column’s style from
column rules, then its cell rules that match, combined.
Sourcepub fn column_style(&self, column: usize) -> Option<&Style>
pub fn column_style(&self, column: usize) -> Option<&Style>
The style column rules give column, if any matched.
Sourcepub fn unresolved(&self) -> Vec<&StyleRule>
pub fn unresolved(&self) -> Vec<&StyleRule>
The rules whose column is not in the table (a header that is not there, an index past the end). They never match.