pub struct StyleRule { /* private fields */ }Expand description
One conditional style. See the module docs.
Implementations
Sourceimpl StyleRule
impl StyleRule
Sourcepub fn new(
column: impl Into<ColumnRef>,
comparison: Comparison,
value: impl Into<Value>,
style: Style,
) -> Self
pub fn new( column: impl Into<ColumnRef>, comparison: Comparison, value: impl Into<Value>, style: Style, ) -> Self
Style a cell of column when it compares to value by comparison.
Sourcepub fn when(
column: impl Into<ColumnRef>,
predicate: impl Fn(&Value) -> bool + Send + Sync + 'static,
style: Style,
) -> Self
pub fn when( column: impl Into<ColumnRef>, predicate: impl Fn(&Value) -> bool + Send + Sync + 'static, style: Style, ) -> Self
Style a cell of column when predicate holds for its value.
Sourcepub fn target_kind(&self) -> Target
pub fn target_kind(&self) -> Target
What it styles.