HelpView

Struct HelpView 

pub struct HelpView { /* private fields */ }
A renderable help page for a CommandSpec.

use rich::Console;
use rich_ext::cli_doc::{ArgSpec, CommandSpec, HelpView};

let spec = CommandSpec::new("tool")
    .arg(ArgSpec::option("level").choices(["low", "high"]).default_value("low").help("How much"));
let out = Console::builder().width(80).build().render_to_string(&HelpView::new(&spec));
assert!(out.contains("--level <LEVEL>  How much [default: low] [possible values: low, high]"));

Implementations

Source

impl HelpView

pub fn new(spec: &CommandSpec) -> Self

pub fn for_path(root: &CommandSpec, path: &[&str]) -> Option<Self>

The help for the subcommand at path below root (such as ["config", "show"]), with the full command path in its usage.

pub fn long(self, long: bool) -> Self

Long help (--help): long about and long argument help where given, and a blank line between entries.

pub fn command_path(self, path: impl Into<String>) -> Self

The command as usage shows it, such as rich config.