pub fn render_plain(renderable: &dyn Renderable, width: usize) -> StringExpand description
Render renderable at width through a plain, deterministic target.
Trailing whitespace on each line and trailing blank lines are dropped.
pub fn render_plain(renderable: &dyn Renderable, width: usize) -> StringRender renderable at width through a plain, deterministic target.
Trailing whitespace on each line and trailing blank lines are dropped.